cobrapy
=======

COnstraint-Based Reconstruction and Analysis (COBRA) methods are widely used
for genome-scale modeling of metabolic networks in both prokaryotes and
eukaryotes. COBRApy is a constraint-based modeling package that is designed to
accomodate the biological complexity of the next generation of COBRA models and
provides access to commonly used COBRA methods, such as flux balance analysis,
flux variability analysis, and gene deletion analyses.

To install, please follow the [instructions](INSTALL.md).

The documentation is browseable online at
[readthedocs](https://cobrapy.readthedocs.org/en/latest/)
and can also be
[downloaded](https://readthedocs.org/projects/cobrapy/downloads/).

Please use the [Google Group](http://groups.google.com/group/cobra-pie) for
help. More information about opencobra is available at the
[website](http://opencobra.github.io/).

If you use cobrapy in a scientific publication, please cite
[doi:10.1186/1752-0509-7-74](http://dx.doi.org/doi:10.1186/1752-0509-7-74)

License
-------
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
